@@ -255,7 +255,7 @@ class ExportBase:
     导出基类，用于将统计数据导出到Excel当中
     """
 
-    def __init__(self, getNode, getX, getY, getUnit):
+    def __init__(self, getNode=None, getX=None, getY=None, getUnit=None):
         self.items: [ExportItem] = []
         self.getNode = getNode
         self.getX = getX
@@ -263,6 +263,9 @@ class ExportBase:
         self.getUnit = getUnit
 
     def select(self, nodeName: str, faceId: any, label: str = None):
+        if self.getNode is None or self.getX is None or self.getUnit is None:
+            print("getNode is None, can not invoke select")
+            return self
         node = self.getNode(nodeName)
         if not node:
             print("not exist node: ", node)
@@ -280,6 +283,9 @@ class ExportBase:
         return self
 
     def selectAvg(self, nodeList: [NodeItem], label: str = None):
+        if self.getNode is None or self.getX is None or self.getUnit is None:
+            print("getNode is None, can not invoke selectAvg")
+            return self
         xMerge = []
         yArr = []
 
@@ -313,6 +319,9 @@ class ExportBase:
         return self
 
     def selectSum(self, nodeList: [NodeItem], label: str = None):
+        if self.getNode is None or self.getX is None or self.getUnit is None:
+            print("getNode is None, can not invoke selectSum")
+            return self
         xMerge = []
         yArr = []
 
@@ -373,7 +382,6 @@ class ExportBase:
             units.append("")
             labels.append(item.label)
 
-
         contents = []
         # long name
         contents.append(longNames)
