@@ -294,21 +294,7 @@ class DelayExtractBase:
         return DelayTarget.getUnit(self.delayTarget.name)
 
 
-class DelayExport(DelayExtractBase, ExportBase):
-    """
-    一个用于将延迟统计结果导出到Excel的辅助类
-    """
-
-    def __init__(self, delay: Delay):
-        DelayExtractBase.__init__(self, delay)
-        ExportBase.__init__(self, self.getNode, self.getX, self.getY, self.getUnit)
-
-    @staticmethod
-    def parse(inputFile: str):
-        return DelayExport(Delay.parse(inputFile))
-
-
-class DelayGraph(GraphBase, DelayExtractBase):
+class DelayGraph(GraphBase, DelayExtractBase, ExportBase):
     """
     一个用于实现绘制延迟图的类
     """
@@ -316,14 +302,14 @@ class DelayGraph(GraphBase, DelayExtractBase):
     def __init__(self, delay: Delay):
         GraphBase.__init__(self)
         DelayExtractBase.__init__(self, delay)
-        self.delay = delay
+        ExportBase.__init__(self, self.getNode, self.getX, self.getY, self.getUnit)
 
-    def plot(self, node: str, appId: int, *args,
+    def plot(self, nodeName: str, appId: int, *args,
              color: str = "&&",
              linewidth: float = 2, linestyle: str = "dotted", marker: str = "&&",
              markerfacecolor: str = "none", markersize: float = 6,
              **kwargs):
-        node = self.delay.getByNode(node)
+        node = self.delay.getByNode(nodeName)
         if not node:
             print("not exist node: ", node)
             return self
@@ -331,6 +317,7 @@ class DelayGraph(GraphBase, DelayExtractBase):
             kwargs["label"] = node.Node
         x, y = node.getX(appId, samplingInterval=self.samplingInterval), \
                node.getY(appId, self.delayType, self.delayTarget, self.samplingInterval)
+        self.select(nodeName, appId, kwargs["label"])
         super().innerPlot(x, y, *args,
                           color=color,
                           linewidth=linewidth,
@@ -346,7 +333,10 @@ class DelayGraph(GraphBase, DelayExtractBase):
                 linewidth: float = 2, linestyle: str = "dotted", marker: str = "&&",
                 markerfacecolor: str = "none", markersize: float = 6,
                 **kwargs):
-
+        label = None
+        if "label" in kwargs:
+            label = kwargs["label"]
+        self.selectSum(nodeList, label=label)
         super().innerPlotSum(nodeList, self.getNode, self.getX, self.getY, *args,
                              color=color,
                              linewidth=linewidth,
@@ -362,7 +352,10 @@ class DelayGraph(GraphBase, DelayExtractBase):
                 linewidth: float = 2, linestyle: str = "dotted", marker: str = "&&",
                 markerfacecolor: str = "none", markersize: float = 6,
                 **kwargs):
-
+        label = None
+        if "label" in kwargs:
+            label = kwargs["label"]
+        self.selectAvg(nodeList, label=label)
         self.innerPlotAvg(nodeList, self.getNode, self.getX, self.getY, *args,
                           color=color,
                           linewidth=linewidth,
